==> org.apache.sling.commons.fsclassloader-1.0.14-source-release.zip: org.apache.sling.commons.fsclassloader-1.0.14/src/main/java/org/apache/sling/commons/fsclassloader/impl/FSClassLoaderComponentConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.commons.fsclassloader.impl;

import org.osgi.service.metatype.annotations.AttributeDefinition;
import org.osgi.service.metatype.annotations.ObjectClassDefinition;

/**
 * {@code FSClassLoaderComponentConfig} Describes the declarative services description for the FileSystem Class Loader component.
 */
@ObjectClassDefinition(
        name = "FileSystem Class Loader",
        description = "Uses the file system to store and read class files from."
)
@interface FSClassLoaderComponentConfig {
 
    /**
     * Location of the filesystem compiled scripts cache
     */
	@AttributeDefinition(
            name = "Location of the filesystem compiled scripts cache",
            description = "Controls where the filesystem compiled scripts cache is stored. When the value "
                    + "is set to null (default) the cache is stored on the bundle persistent "
                    + "storage area."
            )
    String fsclassloader_fileSystemCompiledScriptsCacheLocation();
}

==> org.apache.sling.commons.fsclassloader-1.0.16-source-release.zip: org.apache.sling.commons.fsclassloader-1.0.16/src/main/java/org/apache/sling/commons/fsclassloader/impl/FSClassLoaderComponentConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.commons.fsclassloader.impl;

import org.osgi.service.metatype.annotations.AttributeDefinition;
import org.osgi.service.metatype.annotations.ObjectClassDefinition;

/**
 * {@code FSClassLoaderComponentConfig} Describes the declarative services description for the FileSystem Class Loader component.
 */
@ObjectClassDefinition(
        name = "FileSystem Class Loader",
        description = "Uses the file system to store and read class files from.")
@interface FSClassLoaderComponentConfig {

    /**
     * Location of the filesystem compiled scripts cache
     */
    @AttributeDefinition(
            name = "Location of the filesystem compiled scripts cache",
            description = "Controls where the filesystem compiled scripts cache is stored. When the value "
                    + "is set to null (default) the cache is stored on the bundle persistent "
                    + "storage area.")
    String fsclassloader_fileSystemCompiledScriptsCacheLocation();
}
